@@ -1,25 +1,30 @@
-# MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
-
-# MySQL Connector/Python is licensed under the terms of the GPLv2
-# <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-# MySQL Connectors. There are special exceptions to the terms and
-# conditions of the GPLv2 as it is applied to this software, see the
-# FOSS License Exception
-# <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+# Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License, version 2.0, as
+# published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms,
+# as designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an
+# additional permission to link the program and your derivative works
+# with the separately licensed software that they have included with
+# MySQL.
+#
+# Without limiting anything contained in the foregoing, this file,
+# which is part of MySQL Connector/Python, is also subject to the
+# Universal FOSS Exception, version 1.0, a copy of which can be found at
+# http://oss.oracle.com/licenses/universal-foss-exception.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 """Cursor classes using the C Extension
 """
@@ -200,7 +205,7 @@ class CMySQLCursor(MySQLCursorAbstract):
         while True:
             try:
                 if not self.nextset():
-                    raise StopIteration
+                    raise StopIteration  # pylint: disable=R1708
             except errors.InterfaceError as exc:
                 # Result without result set
                 if exc.errno != CR_NO_RESULT_SET:
@@ -280,8 +285,7 @@ class CMySQLCursor(MySQLCursorAbstract):
             """
             if match.group(1):
                 return ""
-            else:
-                return match.group(2)
+            return match.group(2)
 
         tmp = re.sub(RE_SQL_ON_DUPLICATE, '',
                      re.sub(RE_SQL_COMMENT, remove_comments, operation))
@@ -315,8 +319,7 @@ class CMySQLCursor(MySQLCursorAbstract):
                 stmt = stmt.replace(fmt, b','.join(values), 1)
                 self._executed = stmt
                 return stmt
-            else:
-                return None
+            return None
         except (UnicodeDecodeError, UnicodeEncodeError) as err:
             raise errors.ProgrammingError(str(err))
         except Exception as err:
@@ -341,7 +344,7 @@ class CMySQLCursor(MySQLCursorAbstract):
         if re.match(RE_SQL_INSERT_STMT, operation):
             if not seq_params:
                 self._rowcount = 0
-                return
+                return None
             stmt = self._batch_insert(operation, seq_params)
             if stmt is not None:
                 return self.execute(stmt)
@@ -367,6 +370,7 @@ class CMySQLCursor(MySQLCursorAbstract):
                 "Failed executing the operation; {0}".format(err))
 
         self._rowcount = rowcnt
+        return None
 
     @property
     def description(self):
@@ -378,8 +382,7 @@ class CMySQLCursor(MySQLCursorAbstract):
         """Returns the number of rows produced or affected"""
         if self._rowcount == -1:
             return self._affected_rows
-        else:
-            return self._rowcount
+        return self._rowcount
 
     @property
     def lastrowid(self):
@@ -434,14 +437,14 @@ class CMySQLCursor(MySQLCursorAbstract):
             results = []
             while self._cnx.result_set_available:
                 result = self._cnx.fetch_eof_columns()
-                # pylint: disable=W0212,R0204
+                # pylint: disable=W0212
                 if self._raw:
                     cur = CMySQLCursorBufferedRaw(self._cnx._get_self())
                 else:
                     cur = CMySQLCursorBuffered(self._cnx._get_self())
                 cur._executed = "(a result of {0})".format(call)
                 cur._handle_result(result)
-                # pylint: enable=W0212,R0204
+                # pylint: enable=W0212
                 results.append(cur)
                 self._cnx.next_result()
             self._stored_results = results
@@ -453,8 +456,7 @@ class CMySQLCursor(MySQLCursorAbstract):
                 self.execute(select)
 
                 return self.fetchone()
-            else:
-                return tuple()
+            return tuple()
 
         except errors.Error:
             raise
@@ -718,8 +720,7 @@ class CMySQLCursorDict(CMySQLCursor):
         row = super(CMySQLCursorDict, self).fetchone()
         if row:
             return dict(zip(self.column_names, row))
-        else:
-            return None
+        return None
 
     def fetchmany(self, size=1):
         """Returns next set of rows as list of dictionaries"""
@@ -742,8 +743,7 @@ class CMySQLCursorBufferedDict(CMySQLCursorBuffered):
         row = super(CMySQLCursorBufferedDict, self)._fetch_row()
         if row:
             return dict(zip(self.column_names, row))
-        else:
-            return None
+        return None
 
     def fetchall(self):
         res = super(CMySQLCursorBufferedDict, self).fetchall()
@@ -772,8 +772,7 @@ class CMySQLCursorNamedTuple(CMySQLCursor):
         row = super(CMySQLCursorNamedTuple, self).fetchone()
         if row:
             return self.named_tuple(*row)
-        else:
-            return None
+        return None
 
     def fetchmany(self, size=1):
         """Returns next set of rows as list of named tuples"""
@@ -800,8 +799,7 @@ class CMySQLCursorBufferedNamedTuple(CMySQLCursorBuffered):
         row = super(CMySQLCursorBufferedNamedTuple, self)._fetch_row()
         if row:
             return self.named_tuple(*row)
-        else:
-            return None
+        return None
 
     def fetchall(self):
         res = super(CMySQLCursorBufferedNamedTuple, self).fetchall()
